@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application with a shell
 
 package App::Cme::Command::shell ;
-$App::Cme::Command::shell::VERSION = '1.011';
+$App::Cme::Command::shell::VERSION = '1.012';
 use strict;
 use warnings;
 use 5.10.1;
@@ -48,7 +48,18 @@ sub execute {
 
     my ($model, $inst, $root) = $self->init_cme($opt,$args);
 
-    $self->run_shell_ui($root, $inst->application) ;
+    eval { require Term::ReadLine; };
+    my $has_term_readline = $@ ? 0 : 1;
+
+    if ($has_term_readline) {
+        require Config::Model::TermUI;
+        $self->run_shell_ui('Config::Model::TermUI', $inst) ;
+    }
+    else {
+        warn "You should install Term::ReadLine for a more friendly user interface\n";
+        require Config::Model::SimpleUI;
+        $self->run_shell_ui('Config::Model::SimpleUI', $inst) ;
+    }
 }
 
 1;
@@ -65,7 +76,7 @@ App::Cme::Command::shell - Edit the configuration of an application with a shell
 
 =head1 VERSION
 
-version 1.011
+version 1.012
 
 =head1 SYNOPSIS
 
