@@ -10,7 +10,7 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.011';
+$App::Cme::Common::VERSION = '1.012';
 use strict;
 use warnings;
 use 5.10.1;
@@ -54,7 +54,6 @@ sub process_args {
 
     my $root_model = $appli_map->{$application};
     $root_model ||= $application if $opt->{try_app_as_model};
-    say "cme: using $root_model model" unless $opt->{quiet};
 
     Config::Model::Exception::Any->Trace(1) if $opt->{trace};
 
@@ -62,6 +61,8 @@ sub process_args {
         die "Unknown application: $application. Run 'cme list' to list available applications\n";
     }
 
+    say "cme: using $root_model model" unless $opt->{quiet};
+
     if ($opt->{dev}) {
         # ignore $dev if run as root
         if ( $> ) {
@@ -176,13 +177,12 @@ sub run_tk_ui {
     &MainLoop;    # Tk's
 }
 
-sub run_shell_ui ($$) {
-    my ($self, $root, $root_model) = @_;
+sub run_shell_ui ($$$) {
+    my ($self, $term_class, $inst) = @_;
 
-    require Config::Model::TermUI;
-    my $shell_ui = Config::Model::TermUI->new(
-        root   => $root,
-        title  => $root_model . ' configuration',
+    my $shell_ui = $term_class->new (
+        root   => $inst->config_root,
+        title  => $inst->application . ' configuration',
         prompt => ' >',
     );
 
@@ -221,7 +221,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.011
+version 1.012
 
 =head1 SYNOPSIS
 
